//GLSL shader which compute diffuse shading
//light position set in DiffuseShader.cpp
//ZJW 2/2010

//global variable that rarely change
varying vec3 normal;
varying vec3 vertex_to_light;
varying vec2 texc;

uniform sampler2D gloss;
uniform sampler2D light;
uniform float plane;
uniform float intensity;

void main()
{
	if (plane == 1.0)
	{
	    vec4 planeTex = texture2D(light, gl_TexCoord[0].st);
	    const vec4 diffuseMaterial = vec4(0.2, 0.2, 0.2, .5);
	    gl_FragColor = diffuseMaterial*planeTex;
	}
	else if (plane == 2.0)
	{
	    vec4 sum = vec4(0);
        vec2 texcoord = vec2(gl_TexCoord[0]);
        int j;
        int i;

        for( i= -4 ;i < 4; i++)
        {
            for (j = -3; j < 3; j++)
            {
                sum += texture2D(light, texcoord + vec2(j, i)*0.004) * 0.25;
            }
        }
        if (texture2D(light, texcoord).r < 0.3)
        {
            gl_FragColor += sum*sum*0.012 + texture2D(light, texcoord);
        }
        else
        {
            if (texture2D(light, texcoord).r < 0.5)
            {
                gl_FragColor += sum*sum*0.009 + texture2D(light, texcoord);
            }
            else
            {
                gl_FragColor += sum*sum*0.0075 + texture2D(light, texcoord);
            }
        }
	}
	else
	{
	    //normalize the interpolated normal and light
	    vec3 normalVec = normalize(normal);
	    //vec4 sum = vec4(0);
	    //vec4 eye = gl_ModelViewMatrix * gl_Vertex;
        
	    //has no camera transform on light fine for this example
	    vec3 lightVec = normalize(vertex_to_light);

	    //calculate the diffuse contribution
	    float diffuse = clamp(dot(lightVec, normalVec), 0.0, 1.0);

	    //blue diffuse material
	    const vec4 diffuseMaterial = vec4(0.2, 0.2, 0.8, 1);
	    const vec4 specularMaterial = vec4(1, 1, 1, .5);
	    
	    vec4 glossTex = texture2D(gloss, gl_TexCoord[0].st);
	    //combine terms to make color
	    gl_FragColor = diffuse*diffuseMaterial + 0.3*diffuseMaterial;
	    gl_FragColor += glossTex;
	
	
	    /*vec4 blurSample = 0.0;
	    vec4 tmpPix;
	    vec4 offPix;
	    for(int tx =-2;tx<3;tx++)
        {
	        for(int ty =-2;ty<3;ty++)
	        {
		        vec2 uv = gl_TexCoord[0].st;
		        uv.x = uv.x + tx*0.01;
		        uv.y = uv.y + ty*0.01;
		        tmpPix = texture2D(gloss, uv);
		        offPix = -0.3+tmpPix;
		        offPix = offPix * 32;
		        blurSample = blurSample + offPix;
		
	        }	
        }
	    blurSample = blurSample / 256;
	    gl_FragColor += texture2D(gloss, gl_TexCoord[0].st)*2+blurSample*.4;*/

	    /*now add a specular contribution */	
	    vec3 reflect = reflect(lightVec, normalVec);
	    vec3 eye = vec3(1.0-6.5, -1.0-(-1.0), 7.0);
	    vec3 half = normalize(eye-lightVec);
	    float specular = clamp(dot(reflect, half), 0.0, 1.0);
	    specular = pow(specular, 15.0);
	    gl_FragColor += specular*specularMaterial;
	    
        vec4 sum = vec4(0);
        vec2 texcoord = vec2(gl_TexCoord[0]);
        int j;
        int i;

        for( i= -4 ;i < 4; i++)
        {
            for (j = -3; j < 3; j++)
            {
                sum += texture2D(gloss, texcoord + vec2(j, i)*0.004) * 0.25;
            }
        }
        if (texture2D(gloss, texcoord).r < 0.3)
        {
            gl_FragColor += sum*sum*intensity + texture2D(gloss, texcoord);
        }
        else
        {
            if (texture2D(gloss, texcoord).r < 0.5)
            {
                gl_FragColor += sum*sum*0.009 + texture2D(gloss, texcoord);
            }
            else
            {
                gl_FragColor += sum*sum*0.0075 + texture2D(gloss, texcoord);
            }
        }

	}
}
